==> 0.1.3.tar.gz: lib/onairos_button.dart <==
import 'package:flutter/material.dart';
import 'package:onairos/secureAuthService.dart';
import 'overlay.dart';
import 'NoOnairos.dart';


// /Main imported Onaiors button component
class OnairosButtonWrapper1 extends StatefulWidget {
  final Map<String, Map<String, String>> requestData;
  final String returnLink;

  const OnairosButtonWrapper1({
    Key? key,
    required this.requestData,
    required this.returnLink,
  }) : super(key: key);

  @override
  _OnairosButtonWrapperState createState() => _OnairosButtonWrapperState();
}

class _OnairosButtonWrapperState extends State<OnairosButtonWrapper1> {
  Future<void> _openOnairosOverlay(BuildContext context, Function onResolved) async {
    final secureAuthService = SecureAuthService();

    // Retrieve the user's username and key
    Map<String, dynamic> keysToRetrieve = {'username': null, 'key': null};

    // Call retrieveKeys and destructure the return to get username and key
    Map<String, String>? credentials = await secureAuthService.retrieveKeys(keysToRetrieve);

    // Check credentials and individual values for null
    if (credentials == null || credentials['username'] == null || credentials['key'] == null) {
      // Show an error modal or pop the navigator if any credential is null
      showModalBottomSheet(
        context: context,
        backgroundColor: Colors.transparent,
        builder: (BuildContext context) => OnairosPromptModal(
          onClose: () => Navigator.of(context).pop(),
          logoPath: 'assets/images/onairos_logo.png', // Ensure you have the logo image in your assets
        ),
      );
      return; // Ensure we exit after handling the error case
    }

    // Variables are already checked for null, and we know they are not null here
    String username = credentials['username']!;
    String key = credentials['key']!;

    try {
      showModalBottomSheet(
        context: context,
        backgroundColor: Colors.transparent,
        builder: (context) => OnairosOverlay(
          data: widget.requestData ?? {'Default': 'No data'},
          username: username,
          modelKey: key,
          onResolved: onResolved,
        ),
      );
    } catch (e) {
      // Handle any other exceptions that might occur
      showErrorModal(context, 'An error occurred: $e');
      throw 'Could not overlay with ${widget.requestData}';
    }
  }

  void showErrorModal(BuildContext context, String errorMessage) {
    if (mounted) {
      showDialog(
        context: context,
        builder: (context) {
          return AlertDialog(
            title: Text('Error'),
            content: Text(errorMessage),
            actions: [
              TextButton(
                onPressed: () => Navigator.of(context).pop(),
                child: Text('OK'),
              ),
            ],
          );
        },
      );
    }
  }

  @override
  Widget build(BuildContext context) {
    // Rendere Onairs Button
    return OnairosButton(
      requestData: widget.requestData,
      returnLink: widget.returnLink,
      openOnairosOverlay: _openOnairosOverlay,
      onResolved: (apiUrl) {
        // App2 can define how to handle the apiUrl here
      },
    );
  }
}

// Rendered Button which user clicks to open overlay and initiate data request
class OnairosButton extends StatelessWidget {
  final Map<String, Map<String, String>> requestData;
  final String returnLink;
  final Function onResolved;
  final Future<void> Function(BuildContext context, Function onResolved) openOnairosOverlay;

  const OnairosButton({
    Key? key,
    required this.requestData,
    required this.onResolved,
    required this.returnLink,
    required this.openOnairosOverlay,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return ElevatedButton(
      onPressed: () => openOnairosOverlay(context, onResolved),
      child: Image.asset('images/onairos_logo.png'),
      style: ElevatedButton.styleFrom(
        foregroundColor: Colors.grey,
        backgroundColor: Colors.white,
        shape: CircleBorder(),
        padding: EdgeInsets.all(10),
      ),
    );
  }
}

==> 0.1.5.tar.gz: lib/onairos_button.dart <==
import 'package:flutter/material.dart';
import 'package:onairos/secureAuthService.dart';
import 'overlay.dart';
import 'NoOnairos.dart';


// /Main imported Onaiors button component
class OnairosButtonWrapper1 extends StatefulWidget {
  final Map<String, Map<String, String>> requestData;
  final String returnLink;
  final void Function(String apiUrl, String accessToken) onResolved;
  
  const OnairosButtonWrapper1({
    Key? key,
    required this.requestData,
    required this.returnLink,
    required this.onResolved,
  }) : super(key: key);

  @override
  _OnairosButtonWrapperState createState() => _OnairosButtonWrapperState();
}

class _OnairosButtonWrapperState extends State<OnairosButtonWrapper1> {
  Future<void> _openOnairosOverlay(BuildContext context, Function onResolved) async {
    final secureAuthService = SecureAuthService();

    // Retrieve the user's username and key
    Map<String, dynamic> keysToRetrieve = {'username': null, 'key': null};

    // Call retrieveKeys and destructure the return to get username and key
    Map<String, String>? credentials = await secureAuthService.retrieveKeys(keysToRetrieve);

    // Check credentials and individual values for null
    if (credentials == null || credentials['username'] == null || credentials['key'] == null) {
      // Show an error modal or pop the navigator if any credential is null
      showModalBottomSheet(
        context: context,
        backgroundColor: Colors.transparent,
        builder: (BuildContext context) => OnairosPromptModal(
          onClose: () => Navigator.of(context).pop(),
          logoPath: 'assets/images/onairos_logo.png', // Ensure you have the logo image in your assets
        ),
      );
      return; // Ensure we exit after handling the error case
    }

    // Variables are already checked for null, and we know they are not null here
    String username = credentials['username']!;
    String key = credentials['key']!;

    try {
      showModalBottomSheet(
        context: context,
        backgroundColor: Colors.transparent,
        builder: (context) => OnairosOverlay(
          data: widget.requestData ?? {'Default': 'No data'},
          username: username,
          modelKey: key,
          onResolved: onResolved,
        ),
      );
    } catch (e) {
      // Handle any other exceptions that might occur
      showErrorModal(context, 'An error occurred: $e');
      throw 'Could not overlay with ${widget.requestData}';
    }
  }

  void showErrorModal(BuildContext context, String errorMessage) {
    if (mounted) {
      showDialog(
        context: context,
        builder: (context) {
          return AlertDialog(
            title: Text('Error'),
            content: Text(errorMessage),
            actions: [
              TextButton(
                onPressed: () => Navigator.of(context).pop(),
                child: Text('OK'),
              ),
            ],
          );
        },
      );
    }
  }

  @override
  Widget build(BuildContext context) {
    // Rendere Onairs Button
    return OnairosButton(
      requestData: widget.requestData,
      returnLink: widget.returnLink,
      openOnairosOverlay: _openOnairosOverlay,
      onResolved: (apiUrl, accessToken) {
        widget.onResolved;// App2 can define how to handle the apiUrl here
      },
    );
  }
}

// Rendered Button which user clicks to open overlay and initiate data request
class OnairosButton extends StatelessWidget {
  final Map<String, Map<String, String>> requestData;
  final String returnLink;
  final Function onResolved;
  final Future<void> Function(BuildContext context, Function onResolved) openOnairosOverlay;

  const OnairosButton({
    Key? key,
    required this.requestData,
    required this.onResolved,
    required this.returnLink,
    required this.openOnairosOverlay,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return ElevatedButton(
      onPressed: () => openOnairosOverlay(context, onResolved),
      child: Image.asset('images/onairos_logo.png'),
      style: ElevatedButton.styleFrom(
        foregroundColor: Colors.grey,
        backgroundColor: Colors.white,
        shape: CircleBorder(),
        padding: EdgeInsets.all(10),
      ),
    );
  }
}
